@@ -3,10 +3,12 @@ from __future__ import annotations
 from abc import ABC, abstractmethod
 from collections import OrderedDict, deque
 from collections.abc import (
+    AsyncGenerator,
     AsyncIterator,
     Awaitable,
     Callable,
     Collection,
+    Generator,
     Iterable,
     Iterator,
     Mapping,
@@ -71,6 +73,7 @@ from injection.exceptions import (
     ModuleLockError,
     ModuleNotUsedError,
     NoInjectable,
+    SkipInjectable,
 )
 
 """
@@ -360,6 +363,14 @@ class Priority(StrEnum):
 
 type PriorityStr = Literal["low", "high"]
 
+type ContextManagerLikeRecipe[**P, T] = (
+    Callable[P, ContextManager[T]] | Callable[P, AsyncContextManager[T]]
+)
+type GeneratorRecipe[**P, T] = (
+    Callable[P, Generator[T, Any, Any]] | Callable[P, AsyncGenerator[T, Any]]
+)
+type Recipe[**P, T] = Callable[P, T] | Callable[P, Awaitable[T]]
+
 
 @dataclass(eq=False, frozen=True, slots=True)
 class Module(Broker, EventListener):
@@ -411,7 +422,7 @@ class Module(Broker, EventListener):
 
     def injectable[**P, T](
         self,
-        wrapped: Callable[P, T] | Callable[P, Awaitable[T]] | None = None,
+        wrapped: Recipe[P, T] | None = None,
         /,
         *,
         cls: InjectableFactory[T] = SimpleInjectable,
@@ -420,9 +431,7 @@ class Module(Broker, EventListener):
         on: TypeInfo[T] = (),
         mode: Mode | ModeStr = Mode.get_default(),
     ) -> Any:
-        def decorator(
-            wp: Callable[P, T] | Callable[P, Awaitable[T]],
-        ) -> Callable[P, T] | Callable[P, Awaitable[T]]:
+        def decorator(wp: Recipe[P, T]) -> Recipe[P, T]:
             factory = extract_caller(self.make_injected_function(wp) if inject else wp)
             hints = on if ignore_type_hint else (wp, on)
             updater = Updater(
@@ -447,23 +456,10 @@ class Module(Broker, EventListener):
         mode: Mode | ModeStr = Mode.get_default(),
     ) -> Any:
         def decorator(
-            wrapped: Callable[P, T]
-            | Callable[P, Awaitable[T]]
-            | Callable[P, Iterator[T]]
-            | Callable[P, AsyncIterator[T]],
-        ) -> (
-            Callable[P, T]
-            | Callable[P, Awaitable[T]]
-            | Callable[P, Iterator[T]]
-            | Callable[P, AsyncIterator[T]]
-        ):
+            wrapped: Recipe[P, T] | GeneratorRecipe[P, T],
+        ) -> Recipe[P, T] | GeneratorRecipe[P, T]:
             injectable_class: Callable[[Caller[P, Any], str], Injectable[T]]
-            wrapper: (
-                Callable[P, T]
-                | Callable[P, Awaitable[T]]
-                | Callable[P, ContextManager[T]]
-                | Callable[P, AsyncContextManager[T]]
-            )
+            wrapper: Recipe[P, T] | ContextManagerLikeRecipe[P, T]
 
             if isasyncgenfunction(wrapped):
                 hint = get_yield_hint(wrapped)
@@ -588,6 +584,18 @@ class Module(Broker, EventListener):
 
         return SyncInjectedFunction(metadata)
 
+    def make_async_factory[T](
+        self,
+        wrapped: type[T],
+        /,
+        threadsafe: bool = False,
+    ) -> Callable[..., Awaitable[T]]:
+        factory: InjectedFunction[..., T] = self.make_injected_function(
+            wrapped,
+            threadsafe,
+        )
+        return factory.__inject_metadata__.acall
+
     async def afind_instance[T](self, cls: InputType[T]) -> T:
         injectable = self[cls]
         return await injectable.aget_instance()
@@ -613,7 +621,7 @@ class Module(Broker, EventListener):
     async def aget_instance(self, cls, default=None):  # type: ignore[no-untyped-def]
         try:
             return await self.afind_instance(cls)
-        except KeyError:
+        except (KeyError, SkipInjectable):
             return default
 
     @overload
@@ -633,7 +641,7 @@ class Module(Broker, EventListener):
     def get_instance(self, cls, default=None):  # type: ignore[no-untyped-def]
         try:
             return self.find_instance(cls)
-        except KeyError:
+        except (KeyError, SkipInjectable):
             return default
 
     @overload
@@ -739,11 +747,11 @@ class Module(Broker, EventListener):
         module: Module,
         *,
         priority: Priority | PriorityStr = Priority.get_default(),
-    ) -> Iterator[None]:
+    ) -> Iterator[Self]:
         self.use(module, priority=priority)
 
         try:
-            yield
+            yield self
         finally:
             self.stop_using(module)
 
@@ -762,7 +770,7 @@ class Module(Broker, EventListener):
 
         return self
 
-    def load_profile(self, *names: str) -> ContextManager[None]:
+    def load_profile(self, *names: str) -> ContextManager[Self]:
         modules = tuple(self.from_name(name) for name in names)
 
         for module in modules:
@@ -773,8 +781,8 @@ class Module(Broker, EventListener):
         del module, modules
 
         @contextmanager
-        def cleaner() -> Iterator[None]:
-            yield
+        def cleaner() -> Iterator[Self]:
+            yield self
             self.unlock().init_modules()
 
         return cleaner()
@@ -859,29 +867,28 @@ class Dependencies:
     lazy_mapping: Lazy[Mapping[str, Injectable[Any]]]
 
     def __iter__(self) -> Iterator[tuple[str, Any]]:
-        for name, injectable in self.mapping.items():
-            instance = injectable.get_instance()
-            yield name, instance
+        for name, injectable in self.items():
+            with suppress(SkipInjectable):
+                yield name, injectable.get_instance()
 
     async def __aiter__(self) -> AsyncIterator[tuple[str, Any]]:
-        for name, injectable in self.mapping.items():
-            instance = await injectable.aget_instance()
-            yield name, instance
+        for name, injectable in self.items():
+            with suppress(SkipInjectable):
+                yield name, await injectable.aget_instance()
 
     @property
     def are_resolved(self) -> bool:
         return self.lazy_mapping.is_set
 
-    @property
-    def mapping(self) -> Mapping[str, Injectable[Any]]:
-        return ~self.lazy_mapping
-
     async def aget_arguments(self) -> dict[str, Any]:
         return {key: value async for key, value in self}
 
     def get_arguments(self) -> dict[str, Any]:
         return dict(self)
 
+    def items(self) -> Iterator[tuple[str, Injectable[Any]]]:
+        return iter((~self.lazy_mapping).items())
+
     @classmethod
     def from_iterable(cls, iterable: Iterable[tuple[str, Injectable[Any]]]) -> Self:
         lazy_mapping = Lazy(lambda: dict(iterable))
