@@ -7,6 +7,10 @@ __all__ = (
     "ModuleLockError",
     "ModuleNotUsedError",
     "NoInjectable",
+    "ScopeAlreadyDefinedError",
+    "ScopeError",
+    "ScopeUndefinedError",
+    "SkipInjectable",
 )
 
 
@@ -27,6 +31,9 @@ class NoInjectable[T](KeyError, InjectionError):
         return self.__class
 
 
+class SkipInjectable(InjectionError): ...
+
+
 class ModuleError(InjectionError): ...
 
 
@@ -36,4 +43,13 @@ class ModuleLockError(ModuleError): ...
 class ModuleNotUsedError(KeyError, ModuleError): ...
 
 
+class ScopeError(InjectionError): ...
+
+
+class ScopeUndefinedError(LookupError, SkipInjectable, ScopeError): ...
+
+
+class ScopeAlreadyDefinedError(ScopeError): ...
+
+
 class HookError(InjectionError): ...
